diff graal/com.oracle.truffle.api/src/com/oracle/truffle/api/instrument/Probe.java @ 19818:907128d02b31

Truffle/Instrumentation: For clients of Instrumentation, replace the TruffleEventListener interface with two: InstrumentListener, and ASTInstrumentListener. The former is simple, completely Truffle-safe (can't affect Truffle execution), and designed for simple tools. The latter is similar to the previous interface.
author Michael Van De Vanter <michael.van.de.vanter@oracle.com>
date Thu, 12 Mar 2015 18:03:05 -0700
parents 27fe86a6fb49
children e73096245a4c
line wrap: on
line diff
--- a/graal/com.oracle.truffle.api/src/com/oracle/truffle/api/instrument/Probe.java	Thu Mar 12 15:02:01 2015 -0700
+++ b/graal/com.oracle.truffle.api/src/com/oracle/truffle/api/instrument/Probe.java	Thu Mar 12 18:03:05 2015 -0700
@@ -29,6 +29,7 @@
 
 import com.oracle.truffle.api.*;
 import com.oracle.truffle.api.CompilerDirectives.CompilationFinal;
+import com.oracle.truffle.api.instrument.InstrumentationNode.TruffleEvents;
 import com.oracle.truffle.api.nodes.*;
 import com.oracle.truffle.api.source.*;
 import com.oracle.truffle.api.utilities.*;
@@ -41,9 +42,9 @@
  * is intended to persist at the location, even if the specific node instance is
  * {@linkplain Node#replace(Node) replaced}.
  * <p>
  * The effect of a binding is to intercept {@linkplain TruffleEventListener execution events}
  * arriving at the node and notify each attached {@link Instrument} before execution is allowed to
  * proceed to the child.
  * <p>
  * A Probe is "inserted" into a GL node via a call to {@link Node#probe()}. No more than one Probe
  * can be inserted at a node.
@@ -41,9 +42,9 @@
  * {@linkplain Node#replace(Node) replaced}.
  * <p>
- * The effect of a binding is to intercept {@linkplain TruffleEventListener execution events}
- * arriving at the node and notify each attached {@link Instrument} before execution is allowed to
- * proceed to the child.
+ * The effect of a binding is to intercept {@linkplain TruffleEvents execution events} arriving at
+ * the node and notify each attached {@link Instrument} before execution is allowed to proceed to
+ * the child.
  * <p>
  * A Probe is "inserted" into a GL node via a call to {@link Node#probe()}. No more than one Probe